# `unfolded.data-sdk`

Python package for interfacing with [Unfolded](https://unfolded.ai)'s Data SDK.

For more documentation, refer to the [documentation website]https://location.foursquare.com/developer/docs/studio-data-sdk-overview).
